--- old/usr/src/uts/common/klm/nlm_impl.c	2014-07-15 11:25:07.461556972 -0400
+++ new/usr/src/uts/common/klm/nlm_impl.c	2014-07-15 11:25:07.474807873 -0400
@@ -124,6 +124,11 @@
 static const struct timeval nlm_rpctv_zero = { 0,  0 };
 
 /*
+ * Initial timeout for NLM NULL RPC
+ */
+static volatile struct timeval nlm_nullrpc_wait = { 0, 200000 };
+
+/*
  * List of all Zone globals nlm_globals instences
  * linked together.
  */
@@ -527,6 +532,20 @@
 		wait = nlm_rpctv_zero;
 
 	/*
+	 * Default timeout value of 25 seconds can take
+	 * nlm_null_rpc() 150 seconds to return RPC_TIMEDOUT 
+	 * if it uses UDP and the destination port is 
+	 * unreachable.
+	 *
+	 * A shorter timeout value, e.g. 200 milliseconds,
+	 * will cause nlm_null_rpc() to time out after
+	 * 200 * (1 + 2 + 4 + 8 + 16 + 32) = 12.6 seconds
+	 * (with retries set to 5)
+	 */
+	if (procnum == NLM_NULL)
+		wait = nlm_nullrpc_wait;
+
+	/*
 	 * We need to block signals in case of NLM_CANCEL RPC
 	 * in order to prevent interruption of network RPC
 	 * calls.
